bayespy.inference.vmp.nodes.poisson.PoissonDistribution.compute_message_to_parent
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.compute_message_to_parent